==> eiffelstudio-18.01.10.1424.tar: F_code/C49/vu2421.c <==
/*
 * Code for class VUNO_DEFERRED
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "vu2421.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {VUNO_DEFERRED}.make */
void F3369_38626 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4, EIF_REFERENCE arg5)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(8);
	RTLR(0,arg2);
	RTLR(1,arg3);
	RTLR(2,arg4);
	RTLR(3,arg5);
	RTLR(4,Current);
	RTLR(5,tr1);
	RTLR(6,tr2);
	RTLR(7,arg1);
	RTLIU(8);
	
	RTGC;
	{
		/* INLINED CODE (make_vuno) */
		RTAR(Current, arg3);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg3;
		if ((EIF_BOOLEAN)(arg4 != NULL)) {
			tr1 = arg4;
			tr1 = arg4;
		} else {
			tr2 = F2438_27314(RTCW(arg2));
			tr1 = tr2;
			tr1 = tr2;
		}
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) tr1;
		F3276_38194(Current, arg2);
		F3113_37554(Current, arg5);
		/* END INLINED CODE */
	}
	;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_7_) = (EIF_REFERENCE) arg1;
	RTLE;
}

/* {VUNO_DEFERRED}.target_class */
EIF_REFERENCE F3369_38627 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_7_);
}


/* {VUNO_DEFERRED}.print_short_help */
void F3369_38628 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_REFERENCE tr5 = NULL;
	EIF_REFERENCE tr6 = NULL;
	EIF_REFERENCE tr7 = NULL;
	RTCFDT;
	RTLD;
	
	RTLI(9);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLR(4,tr3);
	RTLR(5,tr4);
	RTLR(6,tr5);
	RTLR(7,tr6);
	RTLR(8,tr7);
	RTLIU(9);
	
	RTGC;
	{
		/* INLINED CODE (add_new_line) */
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R14545[Dtype(arg1)-1902])(RTCW(arg1));
		/* END INLINED CODE */
	}
	;
	tr1 = F2940_34173(Current);
	tr2 = RTMS_EX_H("The non-object call uses a target type with a deferred base class {1}.\012\012What to do: Make sure the target type of the non-object call is an effective class type.",160,1183638574);
	tr3 = RTMS_EX_H("compiler.error",14,1616564082);
	tr1 = F109_2138(RTCW(tr1), tr2, tr3);
	{
		static EIF_TYPE_INDEX typarr0[] = {1812,2129,0xFFF9,1,1971,1901,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr3 = RTLNSP2(typres0.id,EO_REF,((EIF_INTEGER_32) 1L),sizeof(EIF_REFERENCE), EIF_FALSE);
		RT_SPECIAL_COUNT(tr3) = 1L;
		memset(tr3, 0, RT_SPECIAL_VISIBLE_SIZE(tr3));
	}
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,1971,2394,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr4 = RTLNTS(typres0.id, 2, 0);
	}
	tr5 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
	((EIF_TYPED_VALUE *)tr4+1)->it_r = tr5;
	RTAR(tr4,tr5);
	
	{
		static EIF_TYPE_INDEX typarr0[] = {2129,0xFFF9,1,1971,1901,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr7 = RTLNRF(typres0.id, (EIF_POINTER) __A1491_716_2, (EIF_POINTER) _A1491_716_2, (EIF_POINTER)(F2395_26407),tr4, 1, 1);
	}
	*((EIF_REFERENCE *)tr3+0) = (EIF_REFERENCE) tr7;
	RTAR(tr3,tr7);
	tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) F1813_17350)(tr3);
	F419_6139(Current, arg1, tr1, tr2);
	{
		/* INLINED CODE (add_new_line) */
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R14545[Dtype(arg1)-1902])(RTCW(arg1));
		/* END INLINED CODE */
	}
	;
	{
		/* INLINED CODE (add_new_line) */
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R14545[Dtype(arg1)-1902])(RTCW(arg1));
		/* END INLINED CODE */
	}
	;
	RTLE;
}

/* {VUNO_DEFERRED}.trace_single_line */
void F3369_38629 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_REFERENCE tr5 = NULL;
	EIF_REFERENCE tr6 = NULL;
	EIF_REFERENCE tr7 = NULL;
	RTCFDT;
	RTLD;
	
	RTLI(9);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLR(4,tr3);
	RTLR(5,tr4);
	RTLR(6,tr5);
	RTLR(7,tr6);
	RTLR(8,tr7);
	RTLIU(9);
	
	RTGC;
	tr1 = F2940_34173(Current);
	tr2 = RTMS_EX_H("Non-object call on a type with deferred base class {1}.",55,1911609134);
	tr3 = RTMS_EX_H("compiler.error",14,1616564082);
	tr1 = F109_2138(RTCW(tr1), tr2, tr3);
	{
		static EIF_TYPE_INDEX typarr0[] = {1812,2129,0xFFF9,1,1971,1901,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr3 = RTLNSP2(typres0.id,EO_REF,((EIF_INTEGER_32) 1L),sizeof(EIF_REFERENCE), EIF_FALSE);
		RT_SPECIAL_COUNT(tr3) = 1L;
		memset(tr3, 0, RT_SPECIAL_VISIBLE_SIZE(tr3));
	}
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,1971,2394,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr4 = RTLNTS(typres0.id, 2, 0);
	}
	tr5 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
	((EIF_TYPED_VALUE *)tr4+1)->it_r = tr5;
	RTAR(tr4,tr5);
	
	{
		static EIF_TYPE_INDEX typarr0[] = {2129,0xFFF9,1,1971,1901,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr7 = RTLNRF(typres0.id, (EIF_POINTER) __A1491_716_2, (EIF_POINTER) _A1491_716_2, (EIF_POINTER)(F2395_26407),tr4, 1, 1);
	}
	*((EIF_REFERENCE *)tr3+0) = (EIF_REFERENCE) tr7;
	RTAR(tr3,tr7);
	tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) F1813_17350)(tr3);
	F419_6139(Current, arg1, tr1, tr2);
	RTLE;
}

void EIF_Minit2421 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C49/vu2421.c <==
/*
 * Code for class VUNO_FEATURE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "vu2421.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {VUNO_FEATURE}.make */
void F3375_38809 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4, EIF_REFERENCE arg5)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(8);
	RTLR(0,arg2);
	RTLR(1,arg3);
	RTLR(2,arg4);
	RTLR(3,arg5);
	RTLR(4,Current);
	RTLR(5,tr1);
	RTLR(6,tr2);
	RTLR(7,arg1);
	RTLIU(8);
	
	RTGC;
	{
		/* INLINED CODE (make_vuno) */
		RTAR(Current, arg3);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg3;
		if ((EIF_BOOLEAN)(arg4 != NULL)) {
			tr1 = arg4;
			tr1 = arg4;
		} else {
			tr2 = F2451_27467(RTCW(arg2));
			tr1 = tr2;
			tr1 = tr2;
		}
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) tr1;
		F3286_38393(Current, arg2);
		F3125_37759(Current, arg5);
		/* END INLINED CODE */
	}
	;
	{
		/* INLINED CODE (e_feature) */
		tr1 = (EIF_REFERENCE)  0;
		tr1 = F2451_27544(RTCW(arg1), *(EIF_INTEGER_32 *)(RTCW(arg1) + O20912[Dtype(arg1)-2450]));
		/* END INLINED CODE */
	}
	tr1 = tr1;
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_7_) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {VUNO_FEATURE}.callee */
EIF_REFERENCE F3375_38810 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_7_);
}


/* {VUNO_FEATURE}.print_short_help */
void F3375_38811 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_REFERENCE tr5 = NULL;
	EIF_REFERENCE tr6 = NULL;
	EIF_REFERENCE tr7 = NULL;
	RTCFDT;
	RTLD;
	
	RTLI(9);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLR(4,tr3);
	RTLR(5,tr4);
	RTLR(6,tr5);
	RTLR(7,tr6);
	RTLR(8,tr7);
	RTLIU(9);
	
	RTGC;
	{
		/* INLINED CODE (add_new_line) */
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R14664[Dtype(arg1)-1915])(RTCW(arg1));
		/* END INLINED CODE */
	}
	;
	tr1 = F2956_34365(Current);
	tr2 = RTMS_EX_H("{1} used in the non-object call is not a class feature.\012\012What to do:\012\011- make sure the non-object call uses a class feature or\012\011- replace the non-object call with an object call.",177,1846539566);
	tr3 = RTMS_EX_H("compiler.error",14,1616564082);
	tr1 = F112_2166(RTCW(tr1), tr2, tr3);
	{
		static EIF_TYPE_INDEX typarr0[] = {1825,2142,0xFFF9,1,1984,1914,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr3 = RTLNSP2(typres0.id,EO_REF,((EIF_INTEGER_32) 1L),sizeof(EIF_REFERENCE), EIF_FALSE);
		RT_SPECIAL_COUNT(tr3) = 1L;
		memset(tr3, 0, RT_SPECIAL_VISIBLE_SIZE(tr3));
	}
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,1984,2443,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr4 = RTLNTS(typres0.id, 2, 0);
	}
	tr5 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
	((EIF_TYPED_VALUE *)tr4+1)->it_r = tr5;
	RTAR(tr4,tr5);
	
	{
		static EIF_TYPE_INDEX typarr0[] = {2142,0xFFF9,1,1984,1914,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr7 = RTLNRF(typres0.id, (EIF_POINTER) __A1534_358_2, (EIF_POINTER) _A1534_358_2, (EIF_POINTER)(F2444_27220),tr4, 1, 1);
	}
	*((EIF_REFERENCE *)tr3+0) = (EIF_REFERENCE) tr7;
	RTAR(tr3,tr7);
	tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) F1826_17480)(tr3);
	F532_7376(Current, arg1, tr1, tr2);
	{
		/* INLINED CODE (add_new_line) */
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R14664[Dtype(arg1)-1915])(RTCW(arg1));
		/* END INLINED CODE */
	}
	;
	{
		/* INLINED CODE (add_new_line) */
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R14664[Dtype(arg1)-1915])(RTCW(arg1));
		/* END INLINED CODE */
	}
	;
	RTLE;
}

/* {VUNO_FEATURE}.trace_single_line */
void F3375_38812 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_REFERENCE tr5 = NULL;
	EIF_REFERENCE tr6 = NULL;
	EIF_REFERENCE tr7 = NULL;
	RTCFDT;
	RTLD;
	
	RTLI(9);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLR(4,tr3);
	RTLR(5,tr4);
	RTLR(6,tr5);
	RTLR(7,tr6);
	RTLR(8,tr7);
	RTLIU(9);
	
	RTGC;
	tr1 = F2956_34365(Current);
	tr2 = RTMS_EX_H("Feature {1} cannot be used in a non-object call.",48,788415790);
	tr3 = RTMS_EX_H("compiler.error",14,1616564082);
	tr1 = F112_2166(RTCW(tr1), tr2, tr3);
	{
		static EIF_TYPE_INDEX typarr0[] = {1825,2142,0xFFF9,1,1984,1914,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr3 = RTLNSP2(typres0.id,EO_REF,((EIF_INTEGER_32) 1L),sizeof(EIF_REFERENCE), EIF_FALSE);
		RT_SPECIAL_COUNT(tr3) = 1L;
		memset(tr3, 0, RT_SPECIAL_VISIBLE_SIZE(tr3));
	}
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,1984,2443,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr4 = RTLNTS(typres0.id, 2, 0);
	}
	tr5 = *(EIF_REFERENCE *)(Current + _REFACS_7_);
	((EIF_TYPED_VALUE *)tr4+1)->it_r = tr5;
	RTAR(tr4,tr5);
	
	{
		static EIF_TYPE_INDEX typarr0[] = {2142,0xFFF9,1,1984,1914,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr7 = RTLNRF(typres0.id, (EIF_POINTER) __A1534_358_2, (EIF_POINTER) _A1534_358_2, (EIF_POINTER)(F2444_27220),tr4, 1, 1);
	}
	*((EIF_REFERENCE *)tr3+0) = (EIF_REFERENCE) tr7;
	RTAR(tr3,tr7);
	tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) F1826_17480)(tr3);
	F532_7376(Current, arg1, tr1, tr2);
	RTLE;
}

void EIF_Minit2421 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
